(visualization)=

# Visualization

In this section you find the reference documentation of the modules contained in
the visualization module.

- {ref}`visualize <visualizationvisualize>`
- {ref}`legend_handlers <visualizationlegendhandlers>`

(visualizationvisualize)=

## visualize

```{eval-rst}
.. automodule:: visualization.visualize
   :members:
```

(visualizationlegendhandlers)=

## legend_handlers

```{eval-rst}
.. automodule:: visualization.legend_handlers
   :members:
```

## plot_camera

```{eval-rst}
.. automodule:: visualization.plot_camera
   :members:
```

(plot-tables)=

## plot_tables

```{eval-rst}
.. automodule:: visualization.plot_tables
   :members:
```
